@@ -1,5 +1,6 @@
 import copy
 import linecache
+import os
 import random
 import re
 from collections import OrderedDict, defaultdict
@@ -182,6 +183,7 @@ class ScaleneJSON:
         pid: int,
         profile_this_code: Callable[[Filename, LineNumber], bool],
         python_alias_dir: Path,
+        program_path: Path,
         profile_memory: bool = True,
     ) -> Dict[str, Any]:
         """Write the profile out."""
@@ -229,6 +231,12 @@ class ScaleneJSON:
             "elapsed_time_sec": stats.elapsed_time,
             "growth_rate": growth_rate,
             "max_footprint_mb": stats.max_footprint,
+            "max_footprint_fname": stats.max_footprint_loc[0]
+            if stats.max_footprint_loc
+            else None,
+            "max_footprint_lineno": stats.max_footprint_loc[1]
+            if stats.max_footprint_loc
+            else None,
             "files": {},
             "gpu": self.gpu,
             "memory": profile_memory,
@@ -319,7 +327,8 @@ class ScaleneJSON:
                 )
 
             # Print out the the profile for the source, line by line.
-            with open(fname, "r", encoding="utf-8") as source_file:
+            full_fname = os.path.normpath(os.path.join(program_path, fname))
+            with open(full_fname, "r", encoding="utf-8") as source_file:
                 code_lines = source_file.readlines()
 
                 output["files"][fname_print] = {
