@@ -14,29 +14,18 @@ import scalene
 class ScalenePreload:
     @staticmethod
     def get_preload_environ(args: argparse.Namespace) -> Dict[str, str]:
-        env = dict()
-
-        # Set allocation sampling window (sync environment variable
-        # name with src/include/sampleheap.hpp).
-        env["SCALENE_ALLOCATION_SAMPLING_WINDOW"] = str(
-            args.allocation_sampling_window
-        )
+        env = {
+            "SCALENE_ALLOCATION_SAMPLING_WINDOW": str(
+                args.allocation_sampling_window
+            )
+        }
 
         # Set environment variables for loading the Scalene dynamic library,
         # which interposes on allocation and copying functions.
-        if sys.platform == "linux":
-            if not args.cpu_only:
-                env["LD_PRELOAD"] = os.path.join(
-                    scalene.__path__[0], "libscalene.so"
-                )
-                # Disable command-line specified PYTHONMALLOC.
-                if "PYTHONMALLOC" in env:
-                    del env["PYTHONMALLOC"]
-
-        elif sys.platform == "darwin":
+        if sys.platform == "darwin":
             if not args.cpu_only:
                 env["DYLD_INSERT_LIBRARIES"] = os.path.join(
-                    scalene.__path__[0], "libscalene.dylib"
+                    scalene.__path__[0].replace(" ", "\ "), "libscalene.dylib"
                 )
                 # Disable command-line specified PYTHONMALLOC.
                 if "PYTHONMALLOC" in env:
@@ -44,6 +33,21 @@ class ScalenePreload:
             # required for multiprocessing support, even without libscalene
             env["OBJC_DISABLE_INITIALIZE_FORK_SAFETY"] = "YES"
 
+        elif sys.platform == "linux":
+            if not args.cpu_only:
+                # Prepend the Scalene library to the LD_PRELOAD list, if any
+                new_ld_preload = os.path.join(
+                    scalene.__path__[0].replace(" ", "\ "), "libscalene.so"
+                )
+                if "LD_PRELOAD" in env:
+                    old_ld_preload = env["LD_PRELOAD"]
+                    env["LD_PRELOAD"] = new_ld_preload + ":" + old_ld_preload
+                else:
+                    env["LD_PRELOAD"] = new_ld_preload
+                # Disable command-line specified PYTHONMALLOC.
+                if "PYTHONMALLOC" in env:
+                    del env["PYTHONMALLOC"]
+
         elif sys.platform == "win32":
             # Force CPU only on Windows for now.
             args.cpu_only = True
@@ -61,13 +65,8 @@ class ScalenePreload:
         # First, check that we are on a supported platform.
         # (x86-64 and ARM only for now.)
         if not args.cpu_only and (
-            (
-                platform.machine() != "x86_64"
-                and platform.machine() != "AMD64"
-                and platform.machine() != "arm64"
-                and platform.machine() != "aarch64"
-            )
-            or struct.calcsize("P") * 8 != 64
+            platform.machine() not in ["x86_64", "AMD64", "arm64", "aarch64"]
+            or struct.calcsize("P") != 8
         ):
             args.cpu_only = True
             print(
@@ -84,9 +83,8 @@ class ScalenePreload:
         # Start a subprocess with the required environment variables,
         # which may include preloading libscalene
         req_env = ScalenePreload.get_preload_environ(args)
-        if not all(k_v in os.environ.items() for k_v in req_env.items()):
+        if any(k_v not in os.environ.items() for k_v in req_env.items()):
             os.environ.update(req_env)
-
             new_args = [
                 sys.executable,
                 "-m",
